Metrics for hyperparameter tuning (pesfit.metrics) — pesfit 0.6.2 documentation

# Metrics for hyperparameter tuning `(pesfit.metrics)`

class `pesfit.metrics.` `GroupRMSE`(fres, nband)

  Group-wise root-mean-square error calculator.

  `group_rmse`(ground_truth)

    Calculate group-wise root-mean-square error.

  `load_all_data`(varname, shape)

    Load all reconstruction data.

  `load_data`(file, varname, shape)

    Load a set of reconstruction data.

  `rmse`(result, ground_truth)

    Calculate root-mean-square error.